( cd usr/lib64 ; rm -rf libgtkspell.so )
( cd usr/lib64 ; ln -sf libgtkspell.so.0.0.0 libgtkspell.so )
( cd usr/lib64 ; rm -rf libgtkspell.so.0 )
( cd usr/lib64 ; ln -sf libgtkspell.so.0.0.0 libgtkspell.so.0 )
